##  What are Projects in LeanIX?
The Project Fact Sheet is one of our ten main fact sheet types, according to our data model. Projects are used to manage or build budgets, see project status and show project impact on application portfolio and their affected user groups.
In addition, orders from each provider can be managed to get a good overview of the budget status. Cost center and controlling reports very often show valuable information only after the fact events, so it is preferable to keep a “real-time” eye on where you spend your money.
